@@ -1,10 +1,10 @@
 "plot.dice" <-
 function(x,...){
-  if(!require(lattice)) stop('The lattice package is needed')
+  if(!requireNamespace('lattice', quietly = TRUE)) stop('The lattice package is needed')
 
-  old.trellis.par <- trellis.par.get()
-  on.exit(trellis.par.set(old.trellis.par))
-  trellis.par.set(theme=col.whitebg())
+  old.trellis.par <- lattice::trellis.par.get()
+  on.exit(lattice::trellis.par.set(old.trellis.par))
+  lattice::trellis.par.set(theme=lattice::col.whitebg())
   df <- as.matrix(x)
   x <- c(df)
   y <- c(col(df)) - 1
@@ -13,7 +13,7 @@ function(x,...){
   xx <- ceiling(sqrt(dim(df)[2]))
   yy <- ceiling( dim(df)[2]/xx )
 
-  invisible(print(xyplot( y~x|g, prepanel=prepanel.dice, panel=panel.dice,
+  invisible(print(lattice::xyplot( y~x|g, prepanel=prepanel.dice, panel=panel.dice,
                          scales=list(draw=FALSE), aspect=yy/xx, strip=FALSE,
                          as.table=TRUE,
                          xlab="", ylab="",...)))
